<?php

namespace Clever\PaymentGateway\Controller\Adminhtml\System\Config;

use Clever\PaymentGateway\Model\CleverPay;
use Magento\Backend\App\Action\Context;
use Magento\Framework\Controller\ResultFactory;

/**
 * Class Authorize
 * @package Clever\PaymentGateway\Controller\Adminhtml\System\Config
 */
class Authorize extends \Magento\Backend\App\Action
{
    /**
     * @var CleverPay
     */
    protected $cleverPay;

    /**
     * Authorize constructor.
     * @param CleverPay $cleverPay
     * @param Context $context
     */
    public function __construct(
        CleverPay $cleverPay,
        Context $context
    ) {
        $this->cleverPay = $cleverPay;
        parent::__construct($context);
    }

    /**
     * {@inheritDoc}
     */
    public function execute()
    {
        $result = $this->resultFactory->create(ResultFactory::TYPE_JSON);
        try {
            $response = $this->cleverPay->checkConnection();
            if (isset($response['result']) && $response['result'] == true) {
                $data = [
                    'error' => false,
                    'msg'   => __('Authorize Successful!')
                ];
            } else {
                $data = [
                    'error' => true,
                    'msg'   => isset($response['message']) ? $response['message'] : __('Authorize fail!')
                ];
            }
        } catch (\Exception $exception) {
            $data = [
                'error' => true,
                'msg'   => $exception->getMessage()
            ];
        }
        return $result->setData($data);
    }
}
