<?php

namespace Clever\PaymentGateway\Controller\Callback;

use Magento\Framework\App\Action\Action;
use Magento\Sales\Model\Order;

/**
 * Class Index
 * @package Clever\PaymentGateway\Controller\Callback
 */
class Index extends Action
{
    /**
     * @var \Magento\Payment\Gateway\Command\CommandPoolInterface
     */
    protected $commandPool;

    /**
     * @var \Clever\PaymentGateway\Helper\Logger\Logger
     */
    protected $logger;

    /**
     * @var \Clever\PaymentGateway\Model\CleverPay
     */
    protected $cleverPay;

    /**
     * @var \Clever\PaymentGateway\Helper\Configuration
     */
    protected $configuration;

    /**
     * @var \Magento\Sales\Model\OrderFactory
     */
    protected $orderModel;

    /**
     * @var \Magento\Framework\Serialize\Serializer\Json
     */
    protected $json;

    /**
     * @var \Magento\Framework\Controller\Result\JsonFactory
     */
    protected $resultJsonFactory;

    /**
     * Index constructor.
     * @param \Magento\Framework\Serialize\Serializer\Json $json
     * @param \Magento\Sales\Model\OrderFactory $orderModel
     * @param \Clever\PaymentGateway\Model\CleverPay $cleverPay
     * @param \Clever\PaymentGateway\Helper\Logger\Logger $logger
     * @param \Clever\PaymentGateway\Helper\Configuration $configuration
     * @param \Magento\Payment\Gateway\Command\CommandPoolInterface $commandPool
     * @param \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory
     * @param \Magento\Framework\App\Action\Context $context
     */
    public function __construct(
        \Magento\Framework\Serialize\Serializer\Json $json,
        \Magento\Sales\Model\OrderFactory $orderModel,
        \Clever\PaymentGateway\Model\CleverPay $cleverPay,
        \Clever\PaymentGateway\Helper\Logger\Logger $logger,
        \Clever\PaymentGateway\Helper\Configuration $configuration,
        \Magento\Payment\Gateway\Command\CommandPoolInterface $commandPool,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory,
        \Magento\Framework\App\Action\Context $context
    ) {
        parent::__construct($context);
        $this->commandPool = $commandPool;
        $this->logger = $logger;
        $this->cleverPay = $cleverPay;
        $this->configuration = $configuration;
        $this->orderModel = $orderModel;
        $this->json = $json;
        $this->resultJsonFactory = $resultJsonFactory;
    }

    /**
     * {@inheritDoc}
     */
    public function execute()
    {
        $responseParams = $this->getRequest()->getParams();
        $this->logger->debug('Params response: '.$this->json->serialize($responseParams));
        $orderIncrementId = $responseParams['order_increment'] ?? '';
        if ($this->isPaidPayment($orderIncrementId)) {
            return $this->resultRedirectFactory->create()->setPath('checkout/onepage/success');
        }
        $info = isset($responseParams['info']) ? $responseParams['info'] : null;
        if ($info && isset($responseParams['action']) && $responseParams['action'] == 'clever_update_order') {
            $info = $this->configuration->decode($info, $this->configuration->getSecretKey());
            $this->logger->debug('Payment Info Data: '.$this->json->serialize($info));
            if ($info && isset($info->transaction_id)) {
                $transaction = $this->cleverPay->confirmPayment($info->transaction_id);
                if (isset($transaction['order_id'])) {
                    /** @var $order \Magento\Sales\Model\Order */
                    $order = $this->orderModel->create();
                    $order->loadByIncrementId($transaction['order_id']);
                    $this->commandPool->get('authorize_capture')->execute(['order' => $order, 'info' => (array) $info]);
                    return $this->resultRedirectFactory->create()->setPath('checkout/onepage/success');
                }
            }
        }
        return $this->resultRedirectFactory->create()->setPath('checkout/onepage/failure');
    }

    /**
     * @param $orderIncrementId
     * @return bool
     */
    private function isPaidPayment($orderIncrementId)
    {
        if (!$orderIncrementId) {
            return false;
        }
        /** @var $order \Magento\Sales\Model\Order */
        $order = $this->orderModel->create();
        $order->loadByIncrementId($orderIncrementId);
        if (!in_array($order->getState(), [Order::STATE_PENDING_PAYMENT, Order::STATE_NEW])) {
            return true;
        }
        return false;
    }
}
