<?php

namespace Clever\PaymentGateway\Gateway\Command;

use Magento\Sales\Model\Order;

/**
 * Class AuthorizeAndCaptureCommand
 * @package Clever\PaymentGateway\Gateway\Command
 */
class AuthorizeAndCaptureCommand implements \Magento\Payment\Gateway\CommandInterface
{
    /**
     * @var Order\Email\Sender\OrderSender
     */
    protected $orderSender;

    /**
     * @var \Magento\Sales\Api\OrderRepositoryInterface
     */
    protected $orderRepository;

    /**
     * AuthorizeAndCaptureCommand constructor.
     * @param Order\Email\Sender\OrderSender $orderSender
     * @param \Magento\Sales\Api\OrderRepositoryInterface $orderRepository
     */
    public function __construct(
        Order\Email\Sender\OrderSender $orderSender,
        \Magento\Sales\Api\OrderRepositoryInterface $orderRepository
    ) {
        $this->orderSender = $orderSender;
        $this->orderRepository = $orderRepository;
    }

    /**
     * @param array $commandSubject
     * @return \Magento\Payment\Gateway\Command\ResultInterface|void|null
     */
    public function execute(array $commandSubject)
    {
        $order = $commandSubject['order'];
        $info = $commandSubject['info'];
        $payment = $order->getPayment();
        $payment->setTransactionId($info['transaction_id']);
        $payment->setAmountAuthorized($order->getTotalDue());
        $payment->setBaseAmountAuthorized($order->getBaseTotalDue());
        $payment->capture(null);
        $order->setState(Order::STATE_PROCESSING);
        $order->setStatus(Order::STATE_PROCESSING);
        $this->orderSender->send($order);
        $this->orderRepository->save($order);
    }
}
