<?php

namespace Clever\PaymentGateway\Model;

use \Magento\Checkout\Model\ConfigProviderInterface;

/**
 * Class AdditionalConfigVars
 * @package Clever\PaymentGateway\Model
 */
class AdditionalConfigVars implements ConfigProviderInterface
{
    /**
     * @var \Magento\Framework\View\Asset\Repository
     */
    protected $assetRepository;

    /**
     * @var \Clever\PaymentGateway\Helper\Configuration
     */
    protected $configuration;

    /**
     * @var \Magento\Framework\UrlInterface
     */
    protected $urlBuilder;

    /**
     * @var CleverPay
     */
    protected $cleverPay;

    /**
     * @var \Magento\Checkout\Model\Session
     */
    protected $checkoutSession;

    /**
     * @var \Magento\Framework\Locale\CurrencyInterface
     */
    protected $currency;

    /**
     * AdditionalConfigVars constructor.
     * @param \Magento\Framework\UrlInterface $urlBuilder
     * @param \Magento\Framework\View\Asset\Repository $assetRepository
     * @param \Clever\PaymentGateway\Helper\Configuration $configuration
     * @param CleverPay $cleverPay
     * @param \Magento\Checkout\Model\Session $checkoutSession
     * @param \Magento\Framework\Locale\CurrencyInterface $currency
     */
    public function __construct(
        \Magento\Framework\UrlInterface $urlBuilder,
        \Magento\Framework\View\Asset\Repository $assetRepository,
        \Clever\PaymentGateway\Helper\Configuration $configuration,
        \Clever\PaymentGateway\Model\CleverPay $cleverPay,
        \Magento\Checkout\Model\Session $checkoutSession,
        \Magento\Framework\Locale\CurrencyInterface $currency
    ) {
        $this->assetRepository = $assetRepository;
        $this->configuration = $configuration;
        $this->urlBuilder = $urlBuilder;
        $this->cleverPay = $cleverPay;
        $this->checkoutSession = $checkoutSession;
        $this->currency = $currency;
    }

    /**
     * @return array
     */
    public function getConfig()
    {
        if (!$this->configuration->isActive()) {
            return [];
        }
        $CurrencySymbol = '';
        $cashBackFinal = 0;
        $quote = $this->checkoutSession->getQuote();
        if ($quote) {
            $cashBack = $this->cleverPay->getCashBack();
            $realCashback = 0;
            if (!empty($cashBack) && is_array($cashBack) && isset($cashBack['cashback_rate'])) {
                $realCashback = $cashBack['cashback_rate'];
            }
            $totalExcludeDiscounts = $quote->getSubtotalWithDiscount();
            $cashBackFinal = ($totalExcludeDiscounts / 100) * $realCashback;

            // Currency symbol
            $currencyCode = $quote->getQuoteCurrencyCode();
            $CurrencySymbol = $this->currency->getCurrency($currencyCode)->getSymbol();
        }

        $additionalVariables['clever_logo'] = $this->assetRepository->getUrl("Clever_PaymentGateway::images/logo.png");
        $additionalVariables['cleverPaymentLogo'] = $this->assetRepository->getUrl("Clever_PaymentGateway::images/payment.svg");
        $additionalVariables['clever_cart'] = $this->assetRepository->getUrl("Clever_PaymentGateway::images/cart.png");
        $additionalVariables['clever_bank'] = $this->assetRepository->getUrl("Clever_PaymentGateway::images/bank.png");
        $additionalVariables['clever_coin'] = $this->assetRepository->getUrl("Clever_PaymentGateway::images/coin.png");
        $additionalVariables['cashback'] = number_format($cashBackFinal, 2, '.', '');
        $additionalVariables['symbol'] = $CurrencySymbol;
        $additionalVariables['getCleverPayUrl'] = $this->urlBuilder->getUrl('clever_pay/order/getCleverPayUrl');
        return $additionalVariables;
    }
}
